# ЧаВо

## Маруся?
Разработчики узнали про существование [скиллов Маруси](https://dev.vk.com/ru/guide){:target="_blank"} только во время написания туториала по aliceio. \
Вероятно, есть возможность переделать эту библиотеку для работы с Марусей без значительных затрат по времени :)

## Мне нужна помощь, куда обратиться?
Заходите в наш [тг-чатик](https://t.me/aliceio_chat) :)
